==> zendframework-1.9.4.tgz: zendframework/Zend/Db/Statement/Exception.php <==
<?php
/**
 * Zend Framework
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://framework.zend.com/license/new-bsd
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@zend.com so we can send you a copy immediately.
 *
 * @category   Zend
 * @package    Zend_Db
 * @subpackage Statement
 * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
 * @license    http://framework.zend.com/license/new-bsd     New BSD License
 * @version    $Id: Exception.php 17860 2009-08-27 22:48:48Z beberlei $
 */

/**
 * @see Zend_Db_Exception
 */
require_once 'Zend/Db/Exception.php';

/**
 * Zend_Db_Statement_Exception
 *
 * @category   Zend
 * @package    Zend_Db
 * @subpackage Statement
 * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
 * @license    http://framework.zend.com/license/new-bsd     New BSD License
 */
class Zend_Db_Statement_Exception extends Zend_Db_Exception
{
    /**
     * @var Exception
     */
    protected $_chainedException = null;

    /**
     * @param string $message
     * @param string|int $code
     * @param Exception $chainedException
     */
    public function __construct($message = null, $code = null, Exception $chainedException=null)
    {
        $this->message = $message;
        $this->code = $code;
        $this->_chainedException = $chainedException;
    }

    /**
     * Check if this general exception has a specific database driver specific exception nested inside.
     * 
     * @return bool
     */
    public function hasChainedException()
    {
        return ($this->_chainedException!==null);
    }

    /**
     * @return Exception|null
     */
    public function getChainedException()
    {
        return $this->_chainedException;
    }
}

==> zendframework-1.10.8.tgz: zendframework/Zend/Db/Statement/Exception.php <==
<?php
/**
 * Zend Framework
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://framework.zend.com/license/new-bsd
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@zend.com so we can send you a copy immediately.
 *
 * @category   Zend
 * @package    Zend_Db
 * @subpackage Statement
 * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
 * @license    http://framework.zend.com/license/new-bsd     New BSD License
 * @version    $Id: Exception.php 20514 2010-01-22 07:57:10Z ralph $
 */

/**
 * @see Zend_Db_Exception
 */
require_once 'Zend/Db/Exception.php';

/**
 * Zend_Db_Statement_Exception
 *
 * @category   Zend
 * @package    Zend_Db
 * @subpackage Statement
 * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
 * @license    http://framework.zend.com/license/new-bsd     New BSD License
 */
class Zend_Db_Statement_Exception extends Zend_Db_Exception
{
    /**
     * Check if this general exception has a specific database driver specific exception nested inside.
     *
     * @return bool
     */
    public function hasChainedException()
    {
        return ($this->getPrevious() !== null);
    }

    /**
     * @return Exception|null
     */
    public function getChainedException()
    {
        return $this->getPrevious();
    }
}
